==> gcc-4.1.2.tar.bz2: gcc-4.1.2/libjava/classpath/org/omg/PortableInterceptor/ForwardRequest.java <==
/* ForwardRequest.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.PortableInterceptor;

import org.omg.CORBA.UserException;
import org.omg.CORBA.portable.IDLEntity;

import java.io.Serializable;

/**
 * The ForwardRequest is thrown by interceptors to forward the request to
 * another target. The field {@link #forward} contains the reference to this
 * alternative location.
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public class ForwardRequest extends UserException implements IDLEntity,
  Serializable
{
  /**
   * Use serialVersionUID (v1.4) for interoperability.
   */
  private static final long serialVersionUID = 2128007517550526397L;

  /**
   * The field forward.
   */
  public org.omg.CORBA.Object forward;

  /**
   * Create ForwardRequest with no explaining
       * message and all fields left unitialised with the default initial java values.
   */
  public ForwardRequest()
  {
  }

  /**
   * Create the ForwardRequest with explaining
   * message and all fields initialised to the given values.
   *
   * @param why a string, explaining, why this exception has been thrown.
   * @param a_forward a value for forward.
   */
  public ForwardRequest(String why, org.omg.CORBA.Object a_forward)
  {
    super(why);
    this.forward = a_forward;
  }

  /**
   * Create the ForwardRequest without explaining
   * message and all fields initialised to the given values.
   *
   * @param a_forward a value for forward.
   */
  public ForwardRequest(org.omg.CORBA.Object a_forward)
  {
    this.forward = a_forward;
  }
}

==> gcc-4.9.0.tar.bz2: gcc-4.9.0/libjava/classpath/org/omg/PortableInterceptor/ForwardRequest.java <==
/* ForwardRequest.java --
   Copyright (C) 2005, 2006 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.PortableInterceptor;

import org.omg.CORBA.UserException;
import org.omg.CORBA.portable.IDLEntity;

import java.io.Serializable;

/**
 * The ForwardRequest is thrown by interceptors to forward the request to
 * another target. The field {@link #forward} contains the reference to this
 * alternative location.
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public final class ForwardRequest extends UserException implements IDLEntity,
  Serializable
{
  /**
   * Use serialVersionUID (v1.4) for interoperability.
   */
  private static final long serialVersionUID = 2128007517550526397L;

  /**
   * The field forward.
   */
  public org.omg.CORBA.Object forward;

  /**
   * Create ForwardRequest with no explaining
       * message and all fields left unitialised with the default initial java values.
   */
  public ForwardRequest()
  {
  }

  /**
   * Create the ForwardRequest with explaining
   * message and all fields initialised to the given values.
   *
   * @param why a string, explaining, why this exception has been thrown.
   * @param a_forward a value for forward.
   */
  public ForwardRequest(String why, org.omg.CORBA.Object a_forward)
  {
    super(why);
    this.forward = a_forward;
  }

  /**
   * Create the ForwardRequest without explaining
   * message and all fields initialised to the given values.
   *
   * @param a_forward a value for forward.
   */
  public ForwardRequest(org.omg.CORBA.Object a_forward)
  {
    this.forward = a_forward;
  }
}
